#!/bin/bash

NUM_ARGS=3

if [ $# -ne $NUM_ARGS ]; then
    echo "
Usage: eCapturePro_remote_update.sh <installer_path> <remote_server_address> <remote_password>

This script installs eCapturePro on a remote server.
Note that this script will install eCapturePro as root, which will prevent the remote server from running
    the eCapturePro UI application.
    The server that will run the eCapturePro UI application must install eCapturePro manually through the 
    installer.

    installer_path: 
        The path of the eCapturePro .run file you wish to install.
    remote_server_address: 
        The address of the remote server of the form <username>@<ip_address>.
        This address will be used to ssh into the remote server.
    remote_password:
        The password on the remote server.
    "
    exit 0
fi

# Args
INSTALLER_PATH=$1
SERVER_ADDRESS=$2
REMOTE_PWD=$3

REMOTE_INSTALLER_PATH="eCaptureProInstaller_remote.run"

echo "Installer path: $INSTALLER_PATH"
echo "Server address: $SERVER_ADDRESS"
echo "Remote password: $REMOTE_PWD"
echo "========================"
echo

echo "Copying installer onto the remote server..."
sshpass -p $REMOTE_PWD scp $INSTALLER_PATH ${SERVER_ADDRESS}:${REMOTE_INSTALLER_PATH}
echo "========================"
echo

echo "Connecting to remote server..."
sshpass -p $REMOTE_PWD ssh $SERVER_ADDRESS "
echo "Updating login environment..."
source /etc/profile
echo "========================"
echo

echo "Removing existing installation..."
if [[ -z "\${ECAPTURE_PRO_DIR}" ]]; then
    echo "eCapturePro not installed"
else
    echo "eCapturePro installed at \${ECAPTURE_PRO_DIR}"
    echo $REMOTE_PWD | sudo -S \${ECAPTURE_PRO_DIR}/maintenancetool purge -c
fi
echo "========================"
echo

echo "Running installer..."
echo $REMOTE_PWD | sudo -S ~/$REMOTE_INSTALLER_PATH install -c --da --al
echo "========================"
echo

echo "Removing installer from remote server..."
rm $REMOTE_INSTALLER_PATH
echo "========================"
echo

exit 0"

echo "Done"